<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name></name>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Peter Mattern &lt;a href=&quot;mailto:pmattern@arcor.de&quot;&gt;pmattern@arcor.de&lt;/a&gt;&lt;br/&gt; [de] German translation, Project</source>
        <translation>&lt;p&gt;Peter Mattern &lt;a href=&quot;mailto:pmattern@arcor.de&quot;&gt;pmattern@arcor.de&lt;/a&gt;&lt;br/&gt; [de] Překlad do němčiny, projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Dimitrios Glentadakis &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;&lt;br/&gt; [el] Greek translation</source>
        <translation>&lt;p&gt;Dimitrios Glentadakis &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;&lt;br/&gt; [el] Překlad do řečtiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</source>
        <translation type="obsolete">&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Překlad do španělštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Laurene Albrand &lt;a href=&quot;mailto:laurenealbrand@outlook.com&quot;&gt;laurenealbrand@outlook.com&lt;/a&gt;&lt;br/&gt; [fr] French translation</source>
        <translation>&lt;p&gt;Laurene Albrand &lt;a href=&quot;mailto:laurenealbrand@outlook.com&quot;&gt;laurenealbrand@outlook.com&lt;/a&gt;&lt;br/&gt; [fr] Překlad do francouzštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Rémi Verschelde &lt;a href=&quot;mailto:remi@verschelde.fr&quot;&gt;remi@verschelde.fr&lt;/a&gt;&lt;br/&gt; [fr] French translation, Project</source>
        <translation>&lt;p&gt;Rémi Verschelde &lt;a href=&quot;mailto:remi@verschelde.fr&quot;&gt;remi@verschelde.fr&lt;/a&gt;&lt;br/&gt; [fr] Překlad do francouzštiny, projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Daniel Napora &lt;a href=&quot;mailto:napcok@gmail.com&quot;&gt;napcok@gmail.com&lt;/a&gt;&lt;br/&gt; Tomasz Przybył &lt;a href=&quot;mailto:fademind@gmail.com&quot;&gt;fademind@gmail.com&lt;/a&gt;&lt;br/&gt; [pl] Polish translation</source>
        <translation>&lt;p&gt;Daniel Napora &lt;a href=&quot;mailto:napcok@gmail.com&quot;&gt;napcok@gmail.com&lt;/a&gt;&lt;br/&gt; Tomasz Przybył &lt;a href=&quot;mailto:fademind@gmail.com&quot;&gt;fademind@gmail.com&lt;/a&gt;&lt;br/&gt; [pl] Překlad do polštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Atilla Öntaş &lt;a href=&quot;mailto:tarakbumba@gmail.com&quot;&gt;tarakbumba@gmail.com&lt;/a&gt;&lt;br/&gt; [tr] Turkish translation</source>
        <translation>&lt;p&gt;Atilla Öntaş &lt;a href=&quot;mailto:tarakbumba@gmail.com&quot;&gt;tarakbumba@gmail.com&lt;/a&gt;&lt;br/&gt; [tr] Překlad do turečtiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Yuri Chornoivan &lt;a href=&quot;mailto:yurchor@ukr.net&quot;&gt;yurchor@ukr.net&lt;/a&gt;&lt;br/&gt; [uk] Ukrainian translation</source>
        <translation>&lt;p&gt;Yuri Chornoivan &lt;a href=&quot;mailto:yurchor@ukr.net&quot;&gt;yurchor@ukr.net&lt;/a&gt;&lt;br/&gt; [uk] Překlad do ukrajinštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;You-Cheng Hsieh &lt;a href=&quot;mailto:yochenhsieh@gmail.com&quot;&gt;yochenhsieh@gmail.com&lt;/a&gt;&lt;br/&gt; [zh_TW] Chinese (Taiwan) translation</source>
        <translation>&lt;p&gt;You-Cheng Hsieh &lt;a href=&quot;mailto:yochenhsieh@gmail.com&quot;&gt;yochenhsieh@gmail.com&lt;/a&gt;&lt;br/&gt; [zh_TW] Překlad do čínštiny (Tchaj-wan)</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;pmav99&lt;br/&gt; Project</source>
        <translation>&lt;p&gt;pmav99&lt;br/&gt; Projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Dutch translation</source>
        <translation>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Překlad do nizozemštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;werthad &lt;a href=&quot;mailto:werthad@gmail.com&quot;&gt;werthad@gmail.com&lt;/a&gt;&lt;br/&gt; [hu] Hungarian translation</source>
        <translation>&lt;p&gt;werthad &lt;a href=&quot;mailto:werthad@gmail.com&quot;&gt;werthad@gmail.com&lt;/a&gt;&lt;br/&gt; [hu] Překlad do maďarštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Artem Vorotnikov &lt;a href=&quot;mailto:artem@vorotnikov.me&quot;&gt;artem@vorotnikov.me&lt;/a&gt;&lt;br/&gt; Sergey Shitikov &lt;a href=&quot;mailto:rw4lll@yandex.ru&quot;&gt;rw4lll@yandex.ru&lt;/a&gt;&lt;br/&gt;Alexey Zakaldaev &lt;a href=&quot;mailto:nelex111@gmail.com&quot;&gt;nelex111@gmail.com&lt;/a&gt;&lt;br/&gt;Liliya Panova&lt;br/&gt; [ru] Russian translation</source>
        <translation>&lt;p&gt;Artem Vorotnikov &lt;a href=&quot;mailto:artem@vorotnikov.me&quot;&gt;artem@vorotnikov.me&lt;/a&gt;&lt;br/&gt; Sergey Shitikov &lt;a href=&quot;mailto:rw4lll@yandex.ru&quot;&gt;rw4lll@yandex.ru&lt;/a&gt;&lt;br/&gt;Alexey Zakaldaev &lt;a href=&quot;mailto:nelex111@gmail.com&quot;&gt;nelex111@gmail.com&lt;/a&gt;&lt;br/&gt;Liliya Panova&lt;br/&gt; [ru] překlad do ruštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt; juancarlospaco &lt;a href=&quot;mailto:JuanCarlosPaco@gmail.com&quot;&gt;JuanCarlosPaco@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation, Project</source>
        <translation>&lt;p&gt; juancarlospaco &lt;a href=&quot;mailto:JuanCarlosPaco@gmail.com&quot;&gt;JuanCarlosPaco@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Překlad do španělštiny, projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;jose1711 &lt;a href=&quot;mailto:jose1711@gmail.com&quot;&gt;jose1711@gmail.com&lt;/a&gt;&lt;br&gt; [sk] Slovak translation, Project</source>
        <translation>&lt;p&gt;jose1711 &lt;a href=&quot;mailto:jose1711@gmail.com&quot;&gt;jose1711@gmail.com&lt;/a&gt;&lt;br&gt; [sk] Překlad do slovenštiny, Project</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Archita Zabaleta &lt;a href=&quot;mailto:architazabaleta@gmail.com&quot;&gt;architazabaleta@gmail.com&lt;/a&gt;&lt;br/&gt; [it] Italian translation</source>
        <translation>&lt;p&gt;Archita Zabaleta &lt;a href=&quot;mailto:architazabaleta@gmail.com&quot;&gt;architazabaleta@gmail.com&lt;/a&gt;&lt;br/&gt; [it] Italský překlad</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>Jiri Podhorecky&lt;br/&gt;Pavel Fric&lt;br/&gt;[cs] Czech translation</source>
        <translation>Jiří Podhorecký&lt;br/&gt;Pavel Fric&lt;br/&gt;[cs] Czech translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Jürgen Thurau &lt;a href=&quot;mailto:linux@psyca.de&quot;&gt;linux@psyca.de&lt;/a&gt;&lt;br/&gt;[de] German translation</source>
        <translation>&lt;p&gt;Jürgen Thurau &lt;a href=&quot;mailto:linux@psyca.de&quot;&gt;linux@psyca.de&lt;/a&gt;&lt;br/&gt;[de] Překlad do němčiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Masamichi Ito &lt;a href=&quot;https://github.com/ito32bit&quot;&gt;https://github.com/ito32bit&lt;/a&gt;&lt;br/&gt; [ja] Japanese translation</source>
        <translation>&lt;p&gt;Masamichi Ito &lt;a href=&quot;https://github.com/ito32bit&quot;&gt;https://github.com/ito32bit&lt;/a&gt;&lt;br/&gt; [ja] Překlad do japonštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Adrian Moise&lt;a href=&quot;mailto:sah.mat.ro@gmail.com&quot;&gt;sah.mat.ro@gmail.com&lt;/a&gt;&lt;br/&gt; [ro] Romanian translation</source>
        <translation>&lt;p&gt;Adrian Moise&lt;a href=&quot;mailto:sah.mat.ro@gmail.com&quot;&gt;sah.mat.ro@gmail.com&lt;/a&gt;&lt;br/&gt; [ro] Překlad do rumunštiny</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; Teo Laírla (teolairlasg) &lt;a href=&quot;mailto:teo.lairla@iessierradeguara.com&quot;&gt;teo.lairla@iessierradeguara.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;standreas &lt;a href=&quot;mailto:standreas@riseup.net&quot;&gt;standreas@riseup.net&lt;/a&gt;&lt;br/&gt; [it] Italian translation, Weblate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about_dlg.py" line="23"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="24"/>
        <source>Contributors</source>
        <translation>Přispěvatelé</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="46"/>
        <source>About Meteo-qt</source>
        <translation>O programu Meteo-qt</translation>
    </message>
</context>
<context>
    <name>Action to open the dialog with the weather alerts</name>
    <message>
        <location filename="../meteo_qt.py" line="149"/>
        <source>&amp;Alerts</source>
        <comment>Systray icon context menu</comment>
        <translation>&amp;Upozornění</translation>
    </message>
</context>
<context>
    <name>Action to refresh the weather infos from the server</name>
    <message>
        <location filename="../meteo_qt.py" line="141"/>
        <source>&amp;Refresh</source>
        <comment>Systray icon context menu</comment>
        <translation>&amp;Obnovit</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 1</name>
    <message>
        <location filename="../meteo_qt.py" line="488"/>
        <source>Good</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Dobré</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 2</name>
    <message>
        <location filename="../meteo_qt.py" line="493"/>
        <source>Fair</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Příznivé</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 3</name>
    <message>
        <location filename="../meteo_qt.py" line="498"/>
        <source>Moderate</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Mírné </translation>
    </message>
</context>
<context>
    <name>Air Quality Index 4</name>
    <message>
        <location filename="../meteo_qt.py" line="503"/>
        <source>Poor</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Špatné</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 5</name>
    <message>
        <location filename="../meteo_qt.py" line="508"/>
        <source>Very Poor</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Velmi špatné</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 0 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="192"/>
        <source>Sea: Sea like a mirror
Land: Calm. Smoke rises vertically</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Moře: Moře jako zrcadlo
Země: Klid. Kouř stoupá svisle vzhůru</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 1 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="197"/>
        <source>Sea: Ripples with the appearance of scales are formed,but without foam crests
Land: Smoke drift indicates wind direction. Leaves and wind vanes are stationary</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: vznikají zčeřené vlnky, ale bez pěnových hřebenů
Na zemi: Proud kouře udává směr větru. Listy a větrné lopatky se nehýbají</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 10 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="267"/>
        <source>Sea: Very high waves with overhanging crests. Large patches of foam from wave crests give the sea a white appearance. Considerable tumbling of waves with heavy impact. Large amounts of airborne spray reduce visibility
Land: Trees are broken off or uprooted, structural damage likely</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Velmi vysoké vlny s převislými hřebeny. Velké skvrny pěny z vlnových hřebenů dávají moři bílý vzhled. Výrazné překlápění vln s velkým dopadem. Velké množství rozprašované vody do vzduchu snižuje viditelnost
Na zemi: Stromy jsou polámané nebo vytrhané z kořenů, je pravděpodobné poškození staveb</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 11 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="277"/>
        <source>Sea: Exceptionally high waves. Very large patches of foam, driven before the wind, cover much of the sea surface. Very large amounts of airborne spray severely reduce visibility
Land: Widespread vegetation and structural damage likely</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Výjimečně vysoké vlny. Velkou část mořského povrchu pokrývají velmi velké pěnové skvrny, poháněné větrem. Velmi velké množství rozprašované vody do vzduchu výrazně snižuje viditelnost
Na zemi: Pravděpodobně se vyskytují rozsáhlé škody na stavbách a na rostlinstvu. </translation>
    </message>
</context>
<context>
    <name>Beaufort scale 12 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="285"/>
        <source>Sea: Huge waves. Sea is completely white with foam and spray. Air is filled with driving spray, greatly reducing visibility
Land: Severe widespread damage to vegetation and structures. Debris and unsecured objects are hurled about</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Obrovské vlny. Moře je zcela bílé s pěnou a vodní tříští. Vzduch je plný vodních kapek, což výrazně snižuje viditelnost
Na zemi: Silné rozsáhlé poškození rostlinstva a staveb. Odpadky a nezajištěné předměty jsou poházené kolem</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 2 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="204"/>
        <source>Sea: Small wavelets, still short but more pronounced; crests have a glassy appearance and do not break
Land: Wind felt on exposed skin. Leaves rustle. Wind vanes begin to move</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Malé vlnky, stále ještě krátké, ale výraznější; hřebeny mají sklovitý vzhled a nelámou se
Na zemi: Na nezakryté kůži je cítit vítr. Listy šustí. Větrné lopatky se začnou pohybovat</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 3 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="212"/>
        <source>Sea: Large wavelets. Crests begin to break; scattered whitecaps
Land: Leaves and small twigs constantly moving, light flags extended</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Velké vlny. Hřebeny se začnou rozpadat; rozptýlené bílé vrcholky
Na zemi: Listy a malé větvičky se neustále pohybují, lehké vlajky se nadouvají</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 4 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="219"/>
        <source>Sea: Small waves with breaking crests. Fairly frequent whitecaps
Land: Dust and loose paper raised. Small branches begin to move</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Malé vlny s lámavými hřebeny. Docela časté bílé vrcholky
Na zemi: Zvířený prach a poletující papír. Malé větve se začínají pohybovat</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 5 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="226"/>
        <source>Sea: Moderate waves of some length. Many whitecaps. Small amounts of spray
Land: Branches of a moderate size move. Small trees in leaf begin to sway</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Mírné vlny, některé delší. Mnoho bílých vrcholků. Malé množství vodní tříště
Na zemi: Větvičky střední velikosti v pohybu. Malé listnaté stromky se začínají hýbat</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 6 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="233"/>
        <source>Sea: Long waves begin to form. White foam crests are very frequent. Some airborne spray is present
Land: Large branches in motion. Whistling heard in overhead wires. Umbrella use becomes difficult. Empty plastic bins tip over</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Začínají se tvořit dlouhé vlny. Velmi časté jsou bílé pěnové hřebeny. Nějaké vodní kapky ve vzduchu
Na zemi: Velké větve v pohybu. V drátech elektrického napětí  se ozývá pískání. Použití deštníku je obtížné. Prázdné plastové koše se převrhnou</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 7 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="241"/>
        <source>Sea: Sea heaps up. Some foam from breaking waves is blown into streaks along wind direction. Moderate amounts of airborne spray
Land: Whole trees in motion. Effort neededto walk against the wind</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Moře se houpe. Nějaká pěna od lámání vln je foukána do pruhů ve směru větru. Střední množství rozprašované vody do vzduchu
Na zemi: Celé stromy v pohybu. Je třeba vynaložit úsilí, abyste šli proti větru</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 8 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="249"/>
        <source>Sea: Moderately high waves with breaking crests forming spindrift. Well-marked streaks of foam are blown along wind direction. Considerable airborne spray
Land: Some twigs broken from trees. Cars veer on road. Progress on foot is seriously impeded</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Středně vysoké vlny s lámavými hřebeny tvořícími vřeteno. Dobře znatelné pruhy pěny jsou vyfukovány ve směru větru- Silná vodní tříšť ve vzduchu.
Na zemi: Některé větvičky se odlamují ze stromů. Auta jsou na silnici ovlivněná větrem. Pěší chůze je velmi těžká</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 9 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="258"/>
        <source>Sea: High waves whose crests sometimes roll over. Dense foam is blown along wind direction. Large amounts of airborne spray may begin to reduce visibility
Land: Some branches break off trees, and some small trees blow over. Construction/temporary signs and barricades blow over</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Na moři: Vysoké vlny, jejichž hřebeny se občas převalují. Hustá pěna je foukána ve směru větru. Velké množství rozprašovaného vzduchu může snížit viditelnost
Na zemi: Některé větve se ze stromů odlamují a některé malé stromy se vyvrací. Stavební / provizorní značky a ohrazení padají větrem</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <location filename="../citylistdlg.py" line="53"/>
        <source>&amp;Translate</source>
        <comment>Edit cities name</comment>
        <translation>&amp;Překlad</translation>
    </message>
</context>
<context>
    <name>Checkable option to show or not the window at startup</name>
    <message>
        <location filename="../settings.py" line="475"/>
        <source>Start minimized</source>
        <comment>Settings dialogue</comment>
        <translation>Spustit zmenšeno</translation>
    </message>
</context>
<context>
    <name>Checkbox</name>
    <message>
        <location filename="../proxydlg.py" line="49"/>
        <source>Use proxy authentification</source>
        <comment>Proxy settings dialogue</comment>
        <translation>Použít autentizaci proxy</translation>
    </message>
    <message>
        <location filename="../settings.py" line="425"/>
        <source>Connection by proxy</source>
        <comment>Settings dialogue</comment>
        <translation>Připojení pomocí proxy</translation>
    </message>
</context>
<context>
    <name>CityListDlg</name>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Add...</source>
        <translation>&amp;Přidat...</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Remove...</source>
        <translation>&amp;Odstranit...</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Up</source>
        <translation>&amp;Nahoru</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Down</source>
        <translation>&amp;Dolů</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>De&amp;fault</source>
        <translation>&amp;Výchozí</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Sort</source>
        <translation>&amp;Seřadit</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="139"/>
        <source>The city &quot;{0}&quot; has been removed</source>
        <translation>Město &quot;{0}&quot; bylo odstraněno</translation>
    </message>
</context>
<context>
    <name>Comfort level</name>
    <message>
        <location filename="../meteo_qt.py" line="419"/>
        <source>Comfort</source>
        <comment>Weather overview dialogue</comment>
        <translation>Komfortní</translation>
    </message>
</context>
<context>
    <name>Comfort level depending on the dew point</name>
    <message>
        <location filename="../humidex.py" line="32"/>
        <source>Dry</source>
        <comment>Weather info dialogue</comment>
        <translation>Suché</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="46"/>
        <source>Very comfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Velmi pohodlný</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="59"/>
        <source>Comfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Komfortní</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="72"/>
        <source>Alright</source>
        <comment>Weather info dialogue</comment>
        <translation>V pořádku</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="85"/>
        <source>Uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Nepříjemné</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="99"/>
        <source>Very uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Velmi nepříjemné</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="112"/>
        <source>Severely uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Hrozně nepříjemné</translation>
    </message>
</context>
<context>
    <name>Comment about the comfort level depending on the dew point</name>
    <message>
        <location filename="../humidex.py" line="46"/>
        <source>Comfort level excellent for exercise</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation>Úroveň pohodlí vynikající pro cvičení</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="59"/>
        <source>Hard efforts likely not affected</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Pravděpodobné úsilí nebude ovlivněno</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="72"/>
        <source>Expect race times to be slower than in optimal conditions</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Očekávejte, že závod bude pomalejší než za nejvhodnějších podmínek</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="85"/>
        <source>Easy training runs might feel OK but difficult to race well or do hard efforts</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Snadné tréninkové jízdy mohou být pocitově v pořádku, ale bude obtížné dobře závodit nebo vyvinout velké úsilí</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="99"/>
        <source>Expect pace to suffer greatly</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Očekávejte, že tempo bude velmi trpět</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="112"/>
        <source>Avoid the exercise. Skip it or dramatically alter goal.
The comfort level is severely uncomfortable and possibly deadly for asthma sufferers</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation>Vyhněte se cvičení. Přeskočte to nebo dramaticky změňte cíl.
Úroveň pohodlí je pro osoby trpící astmatem velmi nepříjemná a možná smrtící</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="32"/>
        <source>The drier air can cause skin to crack and become irritated more easily</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation>Sušší vzduch může způsobit popraskání kůže a snadnější podráždění</translation>
    </message>
</context>
<context>
    <name>Daylight duration</name>
    <message>
        <location filename="../meteo_qt.py" line="461"/>
        <source>Daylight</source>
        <comment>Weather overview dialogue</comment>
        <translation>Denní světlo</translation>
    </message>
</context>
<context>
    <name>Dew point label</name>
    <message>
        <location filename="../meteo_qt.py" line="408"/>
        <source>Dew point</source>
        <comment>Weather overview dialogue</comment>
        <translation>Rosný bod</translation>
    </message>
</context>
<context>
    <name>Entry label for the proxy port</name>
    <message>
        <location filename="../proxydlg.py" line="39"/>
        <source>Port:</source>
        <comment>Proxy settings dialogue</comment>
        <translation>Přípojka:</translation>
    </message>
</context>
<context>
    <name>Entry label for the proxy url</name>
    <message>
        <location filename="../proxydlg.py" line="27"/>
        <source>Proxy URL:</source>
        <comment>Proxy settings dialogue</comment>
        <translation>Adresa (URL) proxy:</translation>
    </message>
</context>
<context>
    <name>Extreme UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="182"/>
        <source>Take all precautions: Wear SPF 30+ sunscreen, a long-sleeved
                shirt and trousers,&lt;br/&gt;sunglasses, and a very broad hat.
                Avoid the sun within three hours of solar noon.</source>
        <comment>Extreme https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Učiňte veškerá bezpečnostní opatření: Noste krém
na opalování SPF 30+, tričko s dlouhým rukávem a kalhoty,&lt;br/&gt;sluneční brýle a klobouk s velice širokou střechou.
Vyhněte se pobytu na slunci v době slunečního poledne, kdy je slunce po tři hodiny na nejvyšší úrovni.</translation>
    </message>
</context>
<context>
    <name>From the site: Why hPa Is Used - http://n-a-c.biz/WS62694/hPa.htm</name>
    <message>
        <location filename="../conditions.py" line="295"/>
        <source>If the barometric pressure is rising, the weather is improving.
If the barometric pressure is falling, the weather is worsening.
Above 1020 hPa is calm weather/cooler temperatures and below that is unsettled weather/warmer temperatures.
1010-1020 hPa would be weak to normal storms.
990-1010 hPa would be bad storms with possible hurricanes, tornadoes, and typhoons.
Below 990 hPa is the pressure for VERY BAD and POWERFUL hurricanes, tornadoes, and typhoons.</source>
        <comment>Tooltip for the pressure label in weather overview</comment>
        <translation>Pokud barometrický tlak stoupá, počasí se zlepšuje.
Pokud barometrický tlak klesá, počasí se zhoršuje.
Nad 1020 hPa je chladná teplota / chladnější teplota a pod touto teplotou jsou teploty nestabilní.
1010-1020 hPa má sklon k normálním bouřkám.
990-1010 hPa by bylo silná bouře s možnými hurikány, tornády a tajfuny.
Pod 990 hPa je tlak pro VELKÉ hurikány, tornáda a tajfuny.</translation>
    </message>
</context>
<context>
    <name>High UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="171"/>
        <source>Cover the body with sun protective clothing, use SPF 30+
                sunscreen,&lt;br/&gt;wear a hat, reduce time in the sun within three
                hours of solar noon, and wear sunglasses.</source>
        <comment>High https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Zakryjte tělo oblečením chránícím proti slunci, použijte krém na opalování SPF 30+&lt;br/&gt;noste klobouk, omezte čas strávený na slunci v době slunečního poledne, kdy je slunce po tři hodiny na nejvyšší úrovni., a noste sluneční brýle.</translation>
    </message>
</context>
<context>
    <name>If the temperature will be shown with a decimal or rounded in tray icon</name>
    <message>
        <location filename="../settings.py" line="167"/>
        <source>Temperature accuracy in system tray</source>
        <comment>Settings dialogue</comment>
        <translation>Přesnost teploty v oznamovací oblasti panelu</translation>
    </message>
</context>
<context>
    <name>Label before the wind description</name>
    <message>
        <location filename="../meteo_qt.py" line="349"/>
        <source>Wind</source>
        <comment>Weather info panel</comment>
        <translation>Vítr</translation>
    </message>
</context>
<context>
    <name>Label for air quality index (air pollution)</name>
    <message>
        <location filename="../meteo_qt.py" line="473"/>
        <source>Air quality</source>
        <comment>Label in weather info dialogue</comment>
        <translation>Kvalita ovzduší</translation>
    </message>
</context>
<context>
    <name>Label for the cloudiness (%)</name>
    <message>
        <location filename="../meteo_qt.py" line="364"/>
        <source>Cloudiness</source>
        <comment>Weather info panel</comment>
        <translation>Oblačnost</translation>
    </message>
</context>
<context>
    <name>Label for the humidity (%)</name>
    <message>
        <location filename="../meteo_qt.py" line="386"/>
        <source>Humidity</source>
        <comment>Weather info panel</comment>
        <translation>Vlhkost</translation>
    </message>
</context>
<context>
    <name>Label for the pressure (hPa)</name>
    <message>
        <location filename="../meteo_qt.py" line="375"/>
        <source>Pressure</source>
        <comment>Weather info panel</comment>
        <translation>Tlak</translation>
    </message>
</context>
<context>
    <name>Label for the sunrise time (hh:mm)</name>
    <message>
        <location filename="../meteo_qt.py" line="441"/>
        <source>Sunrise</source>
        <comment>Weather info panel</comment>
        <translation>Svítání</translation>
    </message>
</context>
<context>
    <name>Label for the sunset (hh:mm)</name>
    <message>
        <location filename="../meteo_qt.py" line="450"/>
        <source>Sunset</source>
        <comment>Weather info panel</comment>
        <translation>Západ slunce</translation>
    </message>
</context>
<context>
    <name>Label of button to open the proxy dialogue</name>
    <message>
        <location filename="../settings.py" line="438"/>
        <source>Settings</source>
        <comment>Settings dialogue</comment>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>Label of the checkbox</name>
    <message>
        <location filename="../settings.py" line="127"/>
        <source>Wind speed unit</source>
        <comment>Settings dialogue</comment>
        <translation>Jednotka rychlosti větru</translation>
    </message>
</context>
<context>
    <name>Link to create a profile in OpenWeatherMap</name>
    <message>
        <location filename="../settings.py" line="455"/>
        <source>&lt;a href=&quot;http://home.openweathermap.org/users/sign_up&quot;&gt;Create key&lt;/a&gt;</source>
        <comment>Settings dialogue</comment>
        <translation>&lt;a href=&quot;http://home.openweathermap.org/users/sign_up&quot;&gt;Vytvořit klíč&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>Low UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="159"/>
        <source>Wear sunglasses on bright days; use sunscreen if there is
                snow on&lt;br/&gt;the ground, which reflects UV radiation,
                or if you have particularly fair skin.</source>
        <comment>Low https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Noste sluneční brýle při jasných dnech; používejte krém na opalování,
&lt;br/&gt;jestliže na zemi leží sníh, jenž odráží ultrafialové záření, nebo když
máte obzvláště světlou pokožku.</translation>
    </message>
</context>
<context>
    <name>Message when trying to remove thelast and unique city in the list</name>
    <message>
        <location filename="../citylistdlg.py" line="126"/>
        <source>This is the default city!</source>
        <comment>Cities list dialogue</comment>
        <translation>Toto je výchozí město!</translation>
    </message>
</context>
<context>
    <name>MeteoSettings</name>
    <message>
        <location filename="../settings.py" line="50"/>
        <source>City</source>
        <translation>Město</translation>
    </message>
    <message>
        <location filename="../settings.py" line="53"/>
        <source>Click to edit the cities list</source>
        <translation>Klepněte pro upravení seznamu měst</translation>
    </message>
    <message>
        <location filename="../settings.py" line="56"/>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <location filename="../settings.py" line="66"/>
        <source>Bulgarian</source>
        <translation>Bulharský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="67"/>
        <source>Catalan</source>
        <translation>Katalánský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="68"/>
        <source>Czech</source>
        <translation>Český</translation>
    </message>
    <message>
        <location filename="../settings.py" line="69"/>
        <source>Danish</source>
        <translation>Dánský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="70"/>
        <source>German</source>
        <translation>Německý</translation>
    </message>
    <message>
        <location filename="../settings.py" line="71"/>
        <source>Greek</source>
        <translation>Řecký</translation>
    </message>
    <message>
        <location filename="../settings.py" line="72"/>
        <source>English</source>
        <translation>Anglický</translation>
    </message>
    <message>
        <location filename="../settings.py" line="73"/>
        <source>Spanish</source>
        <translation>Španělský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="74"/>
        <source>Finnish</source>
        <translation>Finský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="75"/>
        <source>French</source>
        <translation>Francouzský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="76"/>
        <source>Hebrew</source>
        <translation>Hebrejský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="77"/>
        <source>Croatian</source>
        <translation>Chorvatský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="78"/>
        <source>Hungarian</source>
        <translation>Maďarský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="79"/>
        <source>Italian</source>
        <translation>Italský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="80"/>
        <source>Japanese</source>
        <translation>Japonský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="81"/>
        <source>Lithuanian</source>
        <translation>Litevský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="82"/>
        <source>Norwegian (Bokmaal)</source>
        <translation>Norský (Bokmaal)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="83"/>
        <source>Dutch</source>
        <translation>Holandský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="84"/>
        <source>Polish</source>
        <translation>Polský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="85"/>
        <source>Portuguese</source>
        <translation>Portugalský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="86"/>
        <source>Brazil Portuguese</source>
        <translation>Portugalský (Brazílie)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="87"/>
        <source>Romanian</source>
        <translation>Rumunský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="88"/>
        <source>Russian</source>
        <translation>Ruský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="89"/>
        <source>Slovak</source>
        <translation>Slovenský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="90"/>
        <source>Swedish</source>
        <translation>Švédský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="91"/>
        <source>Turkish</source>
        <translation>Turecký</translation>
    </message>
    <message>
        <location filename="../settings.py" line="92"/>
        <source>Ukrainian</source>
        <translation>Ukrajinský</translation>
    </message>
    <message>
        <location filename="../settings.py" line="93"/>
        <source>Chinese Traditional</source>
        <translation>Čínský (tradiční)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="94"/>
        <source>Chinese Simplified</source>
        <translation>Čínský (zjednodušený)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="113"/>
        <source>Temperature unit</source>
        <translation>Jednotka teploty</translation>
    </message>
    <message>
        <location filename="../settings.py" line="189"/>
        <source>Update interval</source>
        <translation>Obnovovací interval</translation>
    </message>
    <message>
        <location filename="../settings.py" line="190"/>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <location filename="../settings.py" line="213"/>
        <source>Launch at startup</source>
        <translation>Spustit při spuštění</translation>
    </message>
    <message>
        <location filename="../settings.py" line="221"/>
        <source>Font colour in the tray</source>
        <translation>Barva písma v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <location filename="../settings.py" line="227"/>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../settings.py" line="228"/>
        <source>Reset font colour to system default</source>
        <translation>Nastavit barvu písma znovu na výchozí systému</translation>
    </message>
    <message>
        <location filename="../settings.py" line="232"/>
        <source>Notification on weather update</source>
        <translation>Upozornění na změnu počasi</translation>
    </message>
    <message>
        <location filename="../settings.py" line="566"/>
        <source>Meteo-qt Configuration</source>
        <translation>Nastavení Meteo-qt</translation>
    </message>
</context>
<context>
    <name>Moderate UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="165"/>
        <source>Take precautions, such as covering up, if you will be
                outside.&lt;br/&gt;Stay in shade near midday
                when the sun is strongest.</source>
        <comment>Moderate https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Učiňte opatření, například se zakryjte, pokud budete
venku.&lt;br/&gt;Okolo poledne, když je slunce nejsilnější,
zůstaňte ve stínu.</translation>
    </message>
</context>
<context>
    <name>Option for logging level</name>
    <message>
        <location filename="../settings.py" line="489"/>
        <source>Logging level</source>
        <comment>Settings window</comment>
        <translation>Úroveň protokolování</translation>
    </message>
</context>
<context>
    <name>Option to choose the default wind speed unit</name>
    <message>
        <location filename="../settings.py" line="136"/>
        <source>Default</source>
        <comment>Settings diaogue</comment>
        <translation>Výchozí</translation>
    </message>
</context>
<context>
    <name>Option to choose wind speed unit</name>
    <message>
        <location filename="../settings.py" line="141"/>
        <source>Beaufort</source>
        <comment>Settings dialogue</comment>
        <translation>Beaufort</translation>
    </message>
    <message>
        <location filename="../settings.py" line="146"/>
        <source>Km/h</source>
        <comment>Settings dialogue</comment>
        <translation>Km/h</translation>
    </message>
</context>
<context>
    <name>Precipitation type</name>
    <message>
        <location filename="../conditions.py" line="101"/>
        <source>no</source>
        <comment>Weather overview dialogue</comment>
        <translation>Žádné</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="103"/>
        <source>rain</source>
        <comment>Weather overview dialogue</comment>
        <translation>Déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="106"/>
        <source>snow</source>
        <comment>Weather overview dialogue</comment>
        <translation>Sněžení</translation>
    </message>
</context>
<context>
    <name>Precipitation type (no/rain/snow)</name>
    <message>
        <location filename="../meteo_qt.py" line="430"/>
        <source>Precipitation</source>
        <comment>Weather overview dialogue</comment>
        <translation>Přeháňka</translation>
    </message>
</context>
<context>
    <name>Proxy password authentification</name>
    <message>
        <location filename="../proxydlg.py" line="68"/>
        <source>Password:</source>
        <comment>Proxy configuration dialogue</comment>
        <translation>Heslo:</translation>
    </message>
</context>
<context>
    <name>Proxy username authentification</name>
    <message>
        <location filename="../proxydlg.py" line="64"/>
        <source>User ID:</source>
        <comment>Proxy configuration dialogue</comment>
        <translation>ID uživatele:</translation>
    </message>
</context>
<context>
    <name>Search by geolocalisation button tooltip</name>
    <message>
        <location filename="../searchcity.py" line="57"/>
        <source>Find my location</source>
        <comment>Automatic search of my place</comment>
        <translation>Najít moji polohu</translation>
    </message>
</context>
<context>
    <name>Search city</name>
    <message>
        <location filename="../searchcity.py" line="180"/>
        <source>N/A</source>
        <comment>Inserted in search field when the automaticgeolocalisation is not available</comment>
        <translation>Nedostupné</translation>
    </message>
</context>
<context>
    <name>Search city button Tooltip</name>
    <message>
        <location filename="../searchcity.py" line="44"/>
        <source>Search city</source>
        <comment>Search for the given place</comment>
        <translation>Hledat město</translation>
    </message>
</context>
<context>
    <name>Search city dialogue</name>
    <message>
        <location filename="../searchcity.py" line="65"/>
        <source>Start typing the city or the ID or the geographic coordinates &quot;latitude, longitude&quot;</source>
        <comment>Default message in the search field</comment>
        <translation>Začněte psát město nebo ID nebo zeměpisné souřadnice „zeměpisná šířka, délka“</translation>
    </message>
</context>
<context>
    <name>SearchCity</name>
    <message>
        <location filename="../searchcity.py" line="33"/>
        <source>Searching...</source>
        <translation>Hledá se...</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="90"/>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="92"/>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="286"/>
        <source>No results</source>
        <translation>Žádné výsledky</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="288"/>
        <source>Found {0} city</source>
        <translation>Nalezeno {0} město</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="290"/>
        <source>Found {0} cities</source>
        <translation>Nalezeno {0} města</translation>
    </message>
</context>
<context>
    <name>SearchCity window</name>
    <message>
        <location filename="../searchcity.py" line="225"/>
        <source>Please type more than three characters</source>
        <comment>Message in the statusbar</comment>
        <translation>Napište, prosím, více než tři znaky</translation>
    </message>
</context>
<context>
    <name>Settings dialogue</name>
    <message>
        <location filename="../settings.py" line="249"/>
        <source>Icon &amp; temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Ikona a teplota</translation>
    </message>
    <message>
        <location filename="../settings.py" line="254"/>
        <source>Icon</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../settings.py" line="259"/>
        <source>Temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Teplota</translation>
    </message>
    <message>
        <location filename="../settings.py" line="240"/>
        <source>System tray icon</source>
        <comment>Setting to choose the type of the icon on the tray(only icon only text, icon&amp;text</comment>
        <translation>Ikona na hlavním panelu</translation>
    </message>
    <message>
        <location filename="../settings.py" line="264"/>
        <source>Icon &amp; Feels like temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Ikona a pocitová teplota</translation>
    </message>
    <message>
        <location filename="../settings.py" line="269"/>
        <source>Feels like temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Pocitová teplota</translation>
    </message>
    <message>
        <location filename="../settings.py" line="380"/>
        <source>Toggle tray icon interval</source>
        <comment>Label for the option of the checkbox to activate the toggle of the tray icon and temperature</comment>
        <translation>Přepnout interval ikony na liště</translation>
    </message>
    <message>
        <location filename="../settings.py" line="394"/>
        <source>seconds. Set to 0 to deactivate</source>
        <comment>Label after the spinbox to choose the interval to toggle the tray icon and temperature</comment>
        <translation>sekundy. Nastavením na 0 vypněte</translation>
    </message>
    <message>
        <location filename="../settings.py" line="293"/>
        <source>System default</source>
        <comment>ComboBox to choose the system default icons theme</comment>
        <translation>Výchozí pro systém</translation>
    </message>
    <message>
        <location filename="../settings.py" line="299"/>
        <source>Icons theme</source>
        <comment>Tooltip of the ComboBox to choose the icons theme</comment>
        <translation>Vzhled ikon</translation>
    </message>
    <message>
        <location filename="../settings.py" line="410"/>
        <source>Temperature font in system tray</source>
        <comment>Setting for the font size of the temperature in the tray icon</comment>
        <translation>Písmo teploty v systémové liště</translation>
    </message>
    <message>
        <location filename="../settings.py" line="334"/>
        <source>Tray icon size and text position</source>
        <comment>This option concernes 2 dropdown liststo define the size to initialize the tray iconand the position of the temperature text in the icon</comment>
        <translation>Velikost ikony na liště a pozice textu</translation>
    </message>
    <message>
        <location filename="../settings.py" line="343"/>
        <source>Changing this setting you can improve the displaying of the temperature in the tray icon</source>
        <comment>ToolTip of the label &quot;Tray icon size and text position&quot;</comment>
        <translation>Změnou tohoto nastavení můžete zlepšit zobrazování teploty na ikoně v oznamovací oblasti.</translation>
    </message>
    <message>
        <location filename="../settings.py" line="352"/>
        <source>Tray icon initialization size (default size: 64x64)</source>
        <comment>Tooltip of the drowndrop list with icon sizes</comment>
        <translation>Velikost inicializační ikony na liště (výchozí velikost: 64x64)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="371"/>
        <source>Temperature position in the icon (vertically) (default value: -12)</source>
        <comment>ToolTip of the widget (a spinbox) to define the position of the temperature paint in the tray icon</comment>
        <translation>Poloha teploty v ikoně (vertikálně) (výchozí hodnota: -12)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="465"/>
        <source>It is suggested to use a personal key.&lt;br/&gt;If someone hijacks the default meteo-qt key you will not be able to get the weather data (error 401 unauthorized)</source>
        <comment>Tooltip of the api key text field</comment>
        <translation>Doporučujeme používat osobní klíč.Pokud někdo ukradne výchozí klíč meteo-qt, nebudete moci získat data o počasí (chyba 401 neautorizováno).</translation>
    </message>
</context>
<context>
    <name>Status bar message</name>
    <message>
        <location filename="../citylistdlg.py" line="95"/>
        <source>The city already exists in the list</source>
        <comment>Cities list dialogue</comment>
        <translation>Město již v seznamu je</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="106"/>
        <source>Toggle cities with mouse scroll on the weather window</source>
        <comment>Cities list dialogue</comment>
        <translation>Přepnout města projížděním myší na okně s počasím</translation>
    </message>
</context>
<context>
    <name>Status message</name>
    <message>
        <location filename="../searchcity.py" line="116"/>
        <source>Click on &quot;Find my Location&quot; button for automatic geolocation</source>
        <comment>City search dialogue</comment>
        <translation>Klepněte na tlačítko Najít moji polohu pro automatické zjištění zeměpisného umístění</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="126"/>
        <source>Put the city&apos;s name, comma, 2-letter country code (ex: London, GB)</source>
        <comment>City search dialogue</comment>
        <translation>Zadejte název města, čárku, 2-místný kód země (např .: Londýn, GB)</translation>
    </message>
</context>
<context>
    <name>System tray notification</name>
    <message>
        <location filename="../meteo_qt.py" line="2516"/>
        <source>The application has to be restarted to apply the language setting</source>
        <translation>Program je třeba spustit znovu, aby se projevila změna nastavení jazyka</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <location filename="../meteo_qt.py" line="127"/>
        <source>Cities</source>
        <translation>Města</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="140"/>
        <source>&amp;Temporary city</source>
        <translation>&amp;Dočasné město</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="160"/>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="161"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="162"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="180"/>
        <source>Searching weather data...</source>
        <translation>Hledají se data o počasí...</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1971"/>
        <source>Empty list</source>
        <translation>Prázdný seznam</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1990"/>
        <source>No city configured</source>
        <translation>Není nastaveno žádné město</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2004"/>
        <source>No city has been configured yet.</source>
        <translation>Dosud nebylo nastaveno žádné město.</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2004"/>
        <source>Right click on the icon and click on Settings.</source>
        <translation>Klepněte pravým tlačítkem myši na ikonu a pak klepněte na nastavení.</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2584"/>
        <source>Fetching weather data...</source>
        <translation>Natahují se data o počasí...</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2600"/>
        <source>&lt;b&gt;meteo-qt&lt;/b&gt; v{0}
            &lt;br/&gt;License: GPLv3
            &lt;br/&gt;Python {1} - Qt {2} - PyQt {3} on {4}</source>
        <translation>&lt;b&gt;meteo-qt&lt;/b&gt; v{0}
            &lt;br/&gt;Povolení: GPLv3
            &lt;br/&gt;Python {1} - Qt {2} - PyQt {3} on {4}</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="201"/>
        <source>Mon</source>
        <translation>Po</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="202"/>
        <source>Tue</source>
        <translation>Út</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="203"/>
        <source>Wed</source>
        <translation>St</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="204"/>
        <source>Thu</source>
        <translation>Čt</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="205"/>
        <source>Fri</source>
        <translation>Pá</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="206"/>
        <source>Sat</source>
        <translation>So</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="207"/>
        <source>Sun</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="577"/>
        <source>Weather status</source>
        <translation>Stav počasí</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1445"/>
        <source>Min Max Temperature of the day</source>
        <translation>Nejnižší/Nejvyšší teplota dne</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2589"/>
        <source>&lt;p&gt;Author: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;A simple application showing the weather status
            information on the system tray.
            &lt;p&gt;Website: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;Data source: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;This software uses icons from the
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;To translate meteo-qt in your language or contribute to
            current translations, you can use the
            &lt;a href=&quot;https://www.transifex.com/projects/p/meteo-qt/&quot;&gt;
            Transifex&lt;/a&gt; platform.
            &lt;p&gt;If you want to report a dysfunction or a suggestion,
            feel free to open an issue in
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt;.</source>
        <translation type="obsolete">&lt;p&gt;Autor: Dimitrios Glentadakis
&lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
&lt;p&gt;Jednoduchý program ukazující údaje o stavu počasí
v oznamovací oblasti panelu.
&lt;p&gt;Stránky: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
https://github.com/dglent/meteo-qt&lt;/a&gt;
&lt;br/&gt;Zdroj dat: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
OpenWeatherMap&lt;/a&gt;.
&lt;br/&gt;Tento program používá ikony z
&lt;a href=&quot;http://www.kde.org/&quot;&gt;projektu Oxygen&lt;/a&gt;.
&lt;p&gt;K překladu meteo-qt do vašeho jazyka nebo pro
přispění do nynějších překladů můžete použít službu
&lt;a href=&quot;https://www.transifex.com/projects/p/meteo-qt/&quot;&gt;
Transifex&lt;/a&gt;.
&lt;p&gt;Pokud chcete nahlásit špatné fungování nebo něco navrhnout,
klidně tuto otázku otevřete na
&lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
github&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2609"/>
        <source>&lt;p&gt;Author: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;A simple application showing the weather status
            information on the system tray.
            &lt;p&gt;Website: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;Data source: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;This software uses icons from the
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;To translate meteo-qt in your language or contribute to
            current translations, you can use the
            &lt;a href=&quot;https://translate.lxqt-project.org/projects/dglent/meteo-qt/&quot;&gt;
            Weblate&lt;/a&gt; platform.
            &lt;p&gt;If you want to report a dysfunction or a suggestion,
            feel free to open an issue in
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>The Feels Like Temperature</name>
    <message>
        <location filename="../meteo_qt.py" line="181"/>
        <source>Feels like</source>
        <comment>Weather info window</comment>
        <translation>Pocitově</translation>
    </message>
</context>
<context>
    <name>The air quality index is not available</name>
    <message>
        <location filename="../meteo_qt.py" line="483"/>
        <source>Unavailable</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Nedostupné</translation>
    </message>
</context>
<context>
    <name>The key that user can generate in his OpenWeatherMap profile</name>
    <message>
        <location filename="../settings.py" line="448"/>
        <source>OpenWeatherMap key</source>
        <comment>Settings dialogue</comment>
        <translation>Klíč k OpenWeatherMap</translation>
    </message>
</context>
<context>
    <name>Tooltip</name>
    <message>
        <location filename="../settings.py" line="58"/>
        <source>The application has to be restared to apply the language setting</source>
        <comment>Settings dialogue</comment>
        <translation>Program je třeba spustit znovu, aby se projevila změna nastavení jazyka</translation>
    </message>
</context>
<context>
    <name>Tooltip forcast of the day</name>
    <message>
        <location filename="../meteo_qt.py" line="209"/>
        <source>Probability of precipitation</source>
        <comment>Weather info window</comment>
        <translation>Pravděpodobnost srážek</translation>
    </message>
</context>
<context>
    <name>Tooltip of UV label</name>
    <message>
        <location filename="../meteo_qt.py" line="525"/>
        <source>The ultraviolet index at 12 PM</source>
        <comment>Label in weather info dialogue</comment>
        <translation>Ultrafialový index ve 12 hodin</translation>
    </message>
</context>
<context>
    <name>Tooltip on weather icon on 6 days forecast</name>
    <message>
        <location filename="../meteo_qt.py" line="1121"/>
        <source>Day</source>
        <comment>Weather information window</comment>
        <translation>Den</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1126"/>
        <source>Morning</source>
        <comment>Weather information window</comment>
        <translation>Ráno</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1131"/>
        <source>Evening</source>
        <comment>Weather information window</comment>
        <translation>Večer</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1136"/>
        <source>Night</source>
        <comment>Weather information window</comment>
        <translation>Noc</translation>
    </message>
</context>
<context>
    <name>Tootltip forcast of the day</name>
    <message>
        <location filename="../meteo_qt.py" line="1733"/>
        <source>Pressure</source>
        <comment>Weather info window</comment>
        <translation>Tlak</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1738"/>
        <source>Humidity</source>
        <comment>Weather info window</comment>
        <translation>Vlhkost</translation>
    </message>
</context>
<context>
    <name>Tray context menu</name>
    <message>
        <location filename="../meteo_qt.py" line="130"/>
        <source>Toggle Window</source>
        <comment>Open/closes the application window</comment>
        <translation>Přepnout okno</translation>
    </message>
</context>
<context>
    <name>Tray icon</name>
    <message>
        <location filename="../meteo_qt.py" line="2112"/>
        <source>Searching for weather data...</source>
        <comment>Tooltip (when mouse over the icon</comment>
        <translation>Hledají se data o počasí...</translation>
    </message>
</context>
<context>
    <name>Tray notification popup</name>
    <message>
        <location filename="../meteo_qt.py" line="68"/>
        <source>&lt;b&gt;Tomorrow:&lt;/b&gt;</source>
        <comment>Title for the weather conditions</comment>
        <translation>&lt;b&gt;Zítra:&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>UV risk</name>
    <message>
        <location filename="../conditions.py" line="146"/>
        <source>Low</source>
        <translation>Nízké</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="148"/>
        <source>Moderate</source>
        <translation>Mírné</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="151"/>
        <source>High</source>
        <translation>Vysoké</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="153"/>
        <source>Very high</source>
        <translation>Velmi vysoké</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="155"/>
        <source>Extreme</source>
        <translation>Mimořádné</translation>
    </message>
</context>
<context>
    <name>Ultraviolet index</name>
    <message>
        <location filename="../meteo_qt.py" line="516"/>
        <source>UV</source>
        <comment>Label in weather info dialogue</comment>
        <translation>Ultrafialové záření</translation>
    </message>
</context>
<context>
    <name>Ultraviolet index waiting text label</name>
    <message>
        <location filename="../meteo_qt.py" line="786"/>
        <source>Fetching...</source>
        <comment>Weather info dialogue</comment>
        <translation>Načítání...</translation>
    </message>
</context>
<context>
    <name>Unit displayed after the wind speed value and before
                the wind description (keep the spaces before and after)</name>
    <message>
        <location filename="../meteo_qt.py" line="661"/>
        <source> km/h </source>
        <comment>Weather Infos panel</comment>
        <translation> km/h </translation>
    </message>
</context>
<context>
    <name>Very high UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="177"/>
        <source>Wear SPF 30+ sunscreen, a shirt, sunglasses, and a
                wide-brimmed hat.&lt;br/&gt;Do not stay in the sun for too long.</source>
        <comment>Very high https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Noste krém na opalování LSF 30+, košili, sluneční brýle
a klobouk se širokou střechou.&lt;br/&gt;Nezůstávejte na slunci příliš dlouho.</translation>
    </message>
</context>
<context>
    <name>Visibility (distance) label</name>
    <message>
        <location filename="../meteo_qt.py" line="397"/>
        <source>Visibility</source>
        <comment>Weather overview dialogue</comment>
        <translation>Viditelnost</translation>
    </message>
</context>
<context>
    <name>Warning message after pressing OK</name>
    <message>
        <location filename="../settings.py" line="560"/>
        <source>Please add a city</source>
        <comment>Settings dialogue</comment>
        <translation>Přidejte, prosím, město</translation>
    </message>
</context>
<context>
    <name>Warning message after pressing Ok</name>
    <message>
        <location filename="../settings.py" line="555"/>
        <source>Please enter your OpenWeatherMap key</source>
        <comment>Settings dialogue</comment>
        <translation>Zadejte, prosím, svůj klíč k OpenWeatherMap</translation>
    </message>
</context>
<context>
    <name>Warning message in dialog status bar</name>
    <message>
        <location filename="../citytranslate.py" line="55"/>
        <source>The city already exist</source>
        <comment>City translation</comment>
        <translation>Město již je</translation>
    </message>
</context>
<context>
    <name>WeatherConditions</name>
    <message>
        <location filename="../conditions.py" line="8"/>
        <source>thunderstorm with light rain</source>
        <translation>Bouřky a mírný déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="9"/>
        <source>thunderstorm with rain</source>
        <translation>Bouřky s deštěm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="10"/>
        <source>thunderstorm with heavy rain</source>
        <translation>Bouřky a silný déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="11"/>
        <source>light thunderstorm</source>
        <translation>Ojedinělé bouřky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="12"/>
        <source>thunderstorm</source>
        <translation>Bouřky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="13"/>
        <source>heavy thunderstorm</source>
        <translation>Četné bouřky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="14"/>
        <source>ragged thunderstorm</source>
        <translation>Nepravidelné bouřky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="15"/>
        <source>thunderstorm with light drizzle</source>
        <translation>Bouřky a mírné mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="16"/>
        <source>thunderstorm with drizzle</source>
        <translation>Bouřky a mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="17"/>
        <source>thunderstorm with heavy drizzle</source>
        <translation>Bouřky a silné mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="18"/>
        <source>light intensity drizzle</source>
        <translation>Slabé mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="19"/>
        <source>drizzle</source>
        <translation>Mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="20"/>
        <source>heavy intensity drizzle</source>
        <translation>Silné mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="21"/>
        <source>light intensity drizzle rain</source>
        <translation>Slabé mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="22"/>
        <source>drizzle rain</source>
        <translation>Mrholení s deštěm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="23"/>
        <source>heavy intensity drizzle rain</source>
        <translation>Silné mrholení s deštěm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="24"/>
        <source>shower rain and drizzle</source>
        <translation>Dešťové přeháňky a mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="25"/>
        <source>heavy shower rain and drizzle</source>
        <translation>Silné dešťové přeháňky a mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="26"/>
        <source>shower drizzle</source>
        <translation>Přeháňky a mrholení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="27"/>
        <source>light rain</source>
        <translation>Mírný déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="28"/>
        <source>moderate rain</source>
        <translation>Střední déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="29"/>
        <source>heavy intensity rain</source>
        <translation>Silný déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="30"/>
        <source>very heavy rain</source>
        <translation>Velmi silný déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="31"/>
        <source>extreme rain</source>
        <translation>Neobyčejně silný déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="32"/>
        <source>freezing rain</source>
        <translation>Namrzající déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="33"/>
        <source>light intensity shower rain</source>
        <translation>Mírný přeháňkový déšť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="34"/>
        <source>shower rain</source>
        <translation>Dešťové přeháňky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="35"/>
        <source>heavy intensity shower rain</source>
        <translation>Silné dešťové přeháňky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="36"/>
        <source>ragged shower rain</source>
        <translation>Nepravidelné dešťové přeháňky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="37"/>
        <source>light snow</source>
        <translation>Mírné sněžení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="38"/>
        <source>snow</source>
        <translation>Sníh</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="39"/>
        <source>heavy snow</source>
        <translation>Husté sněžení</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="40"/>
        <source>sleet</source>
        <translation>Plískanice</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="41"/>
        <source>shower sleet</source>
        <translation>Dešťové plískanice</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="42"/>
        <source>light rain and snow</source>
        <translation>mírný déšť se sněhem</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="43"/>
        <source>rain and snow</source>
        <translation>Déšť se sněhem</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="44"/>
        <source>light shower snow</source>
        <translation>Mírné sněhové přeháňky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="45"/>
        <source>shower snow</source>
        <translation>Sněhové přeháňky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="46"/>
        <source>heavy shower snow</source>
        <translation>Husté sněhové přeháňky</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="47"/>
        <source>mist</source>
        <translation>Kouřmo</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="48"/>
        <source>smoke</source>
        <translation>Kouř</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="49"/>
        <source>haze</source>
        <translation>Opar</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="50"/>
        <source>sand, dust whirls</source>
        <translation>Písek, víření oblaku prachu</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="51"/>
        <source>fog</source>
        <translation>Mlha</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="52"/>
        <source>sand</source>
        <translation>Písek</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="53"/>
        <source>dust</source>
        <translation>Prach</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="54"/>
        <source>volcanic ash</source>
        <translation>Sopečný popel</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="55"/>
        <source>squalls</source>
        <translation>Náhlý vichr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="62"/>
        <source>tornado</source>
        <translation>Smršť</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="57"/>
        <source>clear sky</source>
        <translation>Jasné nebe</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="58"/>
        <source>few clouds</source>
        <translation>Polojasno</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="59"/>
        <source>scattered clouds</source>
        <translation>Roztroušená oblačnost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="60"/>
        <source>broken clouds</source>
        <translation>Protrhaná oblačnost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="61"/>
        <source>overcast clouds</source>
        <translation>Převážně zataženo</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="63"/>
        <source>tropical storm</source>
        <translation>Tropická bouře</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="80"/>
        <source>hurricane</source>
        <translation>Vichřice</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="65"/>
        <source>cold</source>
        <translation>Chladno</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="66"/>
        <source>hot</source>
        <translation>Horko</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="67"/>
        <source>windy</source>
        <translation>Větrno</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="68"/>
        <source>hail</source>
        <translation>Kroupy</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="69"/>
        <source>calm</source>
        <translation>Bezvětří</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="70"/>
        <source>light breeze</source>
        <translation>Slabý vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="71"/>
        <source>gentle breeze</source>
        <translation>Mírný vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="72"/>
        <source>moderate breeze</source>
        <translation>Dosti čerstvý vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="73"/>
        <source>fresh breeze</source>
        <translation>Čerstvý/ostrý vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="74"/>
        <source>strong breeze</source>
        <translation>Silný vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="75"/>
        <source>high wind, near gale</source>
        <translation>Velmi silný vítr, prudký vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="76"/>
        <source>gale</source>
        <translation>Bouřlivý vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="77"/>
        <source>severe gale</source>
        <translation>Krutý bouřlivý vítr</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="78"/>
        <source>storm</source>
        <translation>Silná vichřice</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="79"/>
        <source>violent storm</source>
        <translation>Mohutná vichřice</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="111"/>
        <source>North</source>
        <translation>Sever</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="112"/>
        <source>NorthEast</source>
        <translation>Severovýchod</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="113"/>
        <source>North-northeast</source>
        <translation>Severoseverovýchod</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="114"/>
        <source>NorthWest</source>
        <translation>Severozápad</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="115"/>
        <source>North-northwest</source>
        <translation>Severoseverozápad</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="116"/>
        <source>South</source>
        <translation>Jih</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="117"/>
        <source>SouthEast</source>
        <translation>Jihovýchod</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="118"/>
        <source>South-southeast</source>
        <translation>Jihojihovýchod</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="119"/>
        <source>SouthWest</source>
        <translation>Jihozápad</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="120"/>
        <source>South-southwest</source>
        <translation>Jihojihozápad</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="121"/>
        <source>East</source>
        <translation>Východ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="122"/>
        <source>East-southeast</source>
        <translation>Východojihovýchod</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="123"/>
        <source>East-northeast</source>
        <translation>Východoseverovýchod</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="124"/>
        <source>West</source>
        <translation>Západ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="125"/>
        <source>West-southwest</source>
        <translation>Západojihozápad</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="126"/>
        <source>West-northwest</source>
        <translation>Západoseverozápad</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="128"/>
        <source>N</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="129"/>
        <source>NE</source>
        <translation>SV</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="130"/>
        <source>NNE</source>
        <translation>SSV</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="131"/>
        <source>NW</source>
        <translation>SZ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="132"/>
        <source>NNW</source>
        <translation>SSZ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="133"/>
        <source>S</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="134"/>
        <source>SE</source>
        <translation>JV</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="135"/>
        <source>SSE</source>
        <translation>JJV</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="136"/>
        <source>SW</source>
        <translation>JZ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="137"/>
        <source>SSW</source>
        <translation>JJZ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="138"/>
        <source>E</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="139"/>
        <source>ESE</source>
        <translation>VJV</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="140"/>
        <source>ENE</source>
        <translation>VSV</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="141"/>
        <source>W</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="142"/>
        <source>WSW</source>
        <translation>ZJZ</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="143"/>
        <source>WNW</source>
        <translation>ZSZ</translation>
    </message>
</context>
<context>
    <name>Window title</name>
    <message>
        <location filename="../citylistdlg.py" line="67"/>
        <source>Cities</source>
        <comment>Cities list dialogue</comment>
        <translation>Města</translation>
    </message>
    <message>
        <location filename="../citytranslate.py" line="38"/>
        <source>City translation</source>
        <comment>City translation dialogue</comment>
        <translation>Překlad názvu města</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="109"/>
        <source>Find a city</source>
        <comment>City search dialogue</comment>
        <translation>Najít město</translation>
    </message>
</context>
<context>
    <name>WorkThread</name>
    <message>
        <location filename="../searchcity.py" line="354"/>
        <source>Data error, please try again later
or modify the name of the city</source>
        <translation>Chyba dat. Zkuste to, prosím, později znovu
nebo změňte název města</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="390"/>
        <source>Please wait, searching...</source>
        <translation>Počkejte, prosím, hledá se...</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="398"/>
        <source>Error: </source>
        <translation>Chyba: </translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="398"/>
        <source>
Try again later</source>
        <translation>Zkuste to později znovu</translation>
    </message>
</context>
</TS>
